function mu_initialize_models
% invoked by mulab
% This is the general list of available components
% This function creates a 
% global structure MU_COMPONENT
% with fields NAME
% PARAMETER.NUMBER double (integer)
% PARAMETER.NAME cell array
% PARAMETER.TYPE cell array (unlim positive limited)
% It further creates the global MU_TABLE
global MU_COMPONENT
global MU_TABLE
MU_COMPONENT=[]; % reset
MU_TABLE=[];     % reset
MU_TABLE.GAMU=0.01355; % MHz/G
MU_TABLE.TAUMU=2197.03; % ns
MU_TABLE.GAME=2.8025; % MHz/G
MU_COMPONENT.NAME={'da'};
MU_COMPONENT.PARAMETER.NUMBER=1;
MU_COMPONENT.PARAMETER.NAME={'lpha'};
MU_COMPONENT.PARAMETER.STEPBOUNDS=[0.01 0 0]; % step lobound hibound
                                              % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION={'mudalpha(p,data)'}; % name of called function
MU_COMPONENT.HELP={'alpha correction'}; % help string
% correction factor, not a component
MU_COMPONENT.NAME(2)={'ba'};  % decaying amplitude, lorentzian or gaussian
MU_COMPONENT.PARAMETER(2).NUMBER=3;
MU_COMPONENT.PARAMETER(2).NAME={'Amp','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(2).STEPBOUNDS=[0.01 0 0; ...
                    0.1 0 0; 0.1 0 0]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(2)={'mubackground(p,data)'}; 
MU_COMPONENT.HELP(2)={['Non-precessing component ' ...
                    ' with Lorentzian/Gaussian relaxation']};
MU_COMPONENT.NAME(3)={'mu'};
MU_COMPONENT.PARAMETER(3).NUMBER=5;
MU_COMPONENT.PARAMETER(3).NAME={'Amp','Gau','Phi','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(3).STEPBOUNDS=[0.01 0 0; ...
                    5 0 0; 10 0 0; ...
                    0.1 0 0; 0.1 0 0]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(3)={'muprecession(p,data)'};
MU_COMPONENT.HELP(3)={['Precessing armonic component ' ...
                    'with Lorentzian/Gaussian relaxation']} ;
MU_COMPONENT.NAME(4)={'bj'};
MU_COMPONENT.PARAMETER(4).NUMBER=5;
MU_COMPONENT.PARAMETER(4).NAME={'Amp','Gau','Phi','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(4).STEPBOUNDS=[0.01 0 0; ...
                    5 0 0; 10 0 0; ...
                    0.1 0 0; 0.1 0 0]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(4)={'mubessel(p,data)'};
MU_COMPONENT.HELP(4)={['Precessing Bessel J0 component ' ...
                    'with Lorentzian/Gaussian relaxation']} ;
MU_COMPONENT.NAME(5)={'st'};
MU_COMPONENT.PARAMETER(5).NUMBER=5;
MU_COMPONENT.PARAMETER(5).NAME={'Amp','Gau','Phi','DecR','Beta'};
MU_COMPONENT.PARAMETER(5).STEPBOUNDS=[0.01 0 0; ...
                    5 0 0; 10 0 0; ...
                    0.1 0.001 1000; 0.1 0.001 1000]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(5)={'mustretched(p,data)'};
MU_COMPONENT.HELP(5)={['Precessing armonic component' ...
                    'with stretched exponential relaxation']} ;
MU_COMPONENT.NAME(6)={'kg'};
MU_COMPONENT.PARAMETER(6).NUMBER=5;
MU_COMPONENT.PARAMETER(6).NAME={'Amp','LFGa','DeG','DeLo','DyNu'};
MU_COMPONENT.PARAMETER(6).STEPBOUNDS=[0.01 0 0; 5 0 0; ...
                    0.1 0.001 1000; 0.1 0.001 1000;...
                   0.001 0 1e5]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(6)={'mukubogau(p,data)'};
MU_COMPONENT.HELP(6)={['Kubo Toyabe suite, Gaussian ' ...
                    'static in zero or longitudinal field, with T1, '...
                    'or dynamic zero field']} ;
MU_COMPONENT.NAME(7)={'kl'};
MU_COMPONENT.PARAMETER(7).NUMBER=4;
MU_COMPONENT.PARAMETER(7).NAME={'Amp','LFGa','DeL','DeLo'};
MU_COMPONENT.PARAMETER(7).STEPBOUNDS=[0.01 0 0; ...
                    5 0 0; ...
                    0.1 0.001 1000; 0.1 0.001 1000]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(7)={'mukubolorentz(p,data)'};
MU_COMPONENT.HELP(7)={['Kubo Toyabe suite, Lorentzian ' ...
                    'static in zero or longitudinal field, with T1']} ;

MU_COMPONENT.NAME(8)={'mt'};
MU_COMPONENT.PARAMETER(8).NUMBER=8;
MU_COMPONENT.PARAMETER(8).NAME={'Amp','Hyp','Gau','Phi',...
                    'DeLo','DeGa','DeLo','DeGa'};
MU_COMPONENT.PARAMETER(8).STEPBOUNDS=[0.01 0 0; ...
                    1 0 0 ; 1 0 0; 10 0 0; ...
                    0.1 0 0; 0.1 0 0; 0.1 0 0; 0.1 0 0 ]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(8)={'muoniumtriplet(p,data)'};
MU_COMPONENT.HELP(8)={['Muonium triplet, ' ...
                    'static in transverse field, with independent rates']} ;

MU_COMPONENT.NAME(9)={'fl'};
MU_COMPONENT.PARAMETER(9).NUMBER=6;
MU_COMPONENT.PARAMETER(9).NAME={'Amp','Gau','Phi',...
                    'Lmbd','Xi','DeGa'};
MU_COMPONENT.PARAMETER(9).STEPBOUNDS=[0.01 0 0; ...
                    1 0 1e5; 1 0 0; 1 0 0; ...
                    0.1 0 0; 0.1 0 0]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(9)={'mufll(p,data)'};
MU_COMPONENT.HELP(9)={['Isotropic Flux Line Lattice, ' ...
                    'London approximation, convoluted with Gaussian']} ;
MU_COMPONENT.NAME(10)={'fm'};
MU_COMPONENT.PARAMETER(10).NUMBER=4;
MU_COMPONENT.PARAMETER(10).NAME={'Amp','Gau',...
                    'DeLo','DeGa'};
MU_COMPONENT.PARAMETER(10).STEPBOUNDS=[0.01 0 0; ...
                    1 0 0; 0.1 0 0; 0.1 0 0]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(10)={'mufmuf(p,data)'};
MU_COMPONENT.HELP(10)={['FMuF polycrystal in zero field, ' ...
                    'with decays']} ;
MU_COMPONENT.NAME(11)={'hm'};
MU_COMPONENT.PARAMETER(11).NUMBER=4;
MU_COMPONENT.PARAMETER(11).NAME={'Amp','Gau',...
                    'LDeL','TDeL'}; % amplitude, 
                                    % dipolar field = mu0 gaF gamu h/(4 pi r^3)
                                    % + two lor decays, one for
                                    % constant (longitudinal) and
                                    % one for like precessions (transverse)
MU_COMPONENT.PARAMETER(11).STEPBOUNDS=[0.01 0 0; ...
                    1 0 0; 0.1 0 0; 0.1 0 0;]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(11)={'mumuh(p,data)'};
MU_COMPONENT.HELP(11)={['MuH polycrystal in zero field, ' ...
                    'with T1, T2 decays']} ;
MU_COMPONENT.NAME(12)={'dm'};
MU_COMPONENT.PARAMETER(12).NUMBER=5;
MU_COMPONENT.PARAMETER(12).NAME={'Amp','Gau',...
                    'NuQ','LDeL','TDeL'}; 
                             % 1 amplitude, 
                             % 2 dipolar field
                             % Bd = mu0 gaF gamu h/(4 pi r^3) (G)
                             % 3 secular quadrupolar frequency 
                             % nu_Q (3 cos^2 beta -1)/4 (kHz)
                             % nu_Q= 3 e Q Vzz /2hS(2S-1) 
                             % with beta = angle between dipolar z axis
                             % and quadrupolar zita axis (eta=0)
                             % + 4 5 two lor decays, one for
                             % constant (longitudinal) and
                             % one for precessions (transverse)
MU_COMPONENT.PARAMETER(12).STEPBOUNDS=[0.01 0 0; ...
                    1 0 0; 0.1 0 0; 0.1 0 0; 0.1 0 0]; 
                    % step lobound hibound
                    % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(12)={'mumud(p,data)'};
MU_COMPONENT.HELP(12)={['MuD polycrystal in zero field, ' ...
                    'with Bdip, nuQzz and T1, T2 decays']} ;

MU_COMPONENT.NAME(13)={'kt'};
MU_COMPONENT.PARAMETER(13).NUMBER=5;
MU_COMPONENT.PARAMETER(13).NAME={'Amp','LFGa','DeGa','DeLo','DyNu'};
MU_COMPONENT.PARAMETER(13).STEPBOUNDS=[0.01 0 0; 5 0 0; ...
                    0.1 0 0; 0.1 0 0;...
                   0.001 0 1e5]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(13)={'mukt(p,data)'};
MU_COMPONENT.HELP(13)={['Kubo Toyabe suite, static or dynamic, Gaussian or Lorentzian ' ...
                    'in zero or longitudinal field, (default Gaussian)']} ;

% FMUF angle from jupyter/fmuf: coefficients of the angular expansion
a = zeros(7,9);
a(1,:) = [3.14294e-01, 2.11339e-01 , -1.28866e+00 , -3.32603e-03 , 3.17144e+01 , 2.93237e+00 , 6.48096e-01 , -1.22463e+01 , -5.20031e+01 ];
a(2,:) = [1.25627e-02, 5.43445e-03 , 2.25489e-02 , -2.82476e-02 , -1.72216e+00 , 9.97997e-01 , 2.45878e-01 , -2.82563e-01 , 1.65940e+01 ];
a(3,:) = [-3.63575e-01, -6.54200e-02 , 2.34553e+00 , 4.76639e-01 , -5.15728e+01 , -5.43851e+00 , -1.64941e+00 , 2.31971e+01 , 6.01945e+01 ];
a(4,:) = [-1.16768e-03, -3.38494e-03 , 4.52925e-02 , -1.09746e-03 , 1.02330e+00 , -2.22788e-01 , 7.07397e-02 , 2.49776e-01 , -8.52406e+00 ];
a(5,:) = [3.34377e-03, 1.11061e-03 , 1.11489e-02 , -6.42877e-03 , -1.12745e-01 , 1.86486e-01 , 3.61962e-02 , 2.52009e-02 , 1.37997e+00 ];
a(6,:) = [3.65606e-02, 5.46798e-02 , 2.82395e-02 , 7.59534e-02 , 6.85000e-01 , 1.28355e-01 , -4.36650e-02 , 3.25272e-01 , -2.49469e+00 ];
a(7,:) = [6.00291e-02, 8.88928e-02 , 2.13539e-02 , 1.14527e-01 , -6.19755e-02 , 5.50073e-01 , -2.94700e-02 , 2.39108e-01 , 2.01638e+00 ];
MU_TABLE.FMUFANGLE_CONSTANTS = a;
a = zeros(7,9);
a(1,:) = [0.00000e+00, 0.00000e+00 , 0.00000e+00 , 0.00000e+00 , 0.00000e+00 , 0.00000e+00 , 0.00000e+00 , 0.00000e+00 , 0.00000e+00 ];
a(2,:) = [1.26779e-01, 1.41727e-01 , 1.15829e-01 , 9.62242e-02 , -1.90059e-01 , 2.70209e+00 , -6.78235e-02 , 1.11922e+00 , 1.79298e+01 ];
a(3,:) = [3.11338e-01, 2.46711e-01 , -1.20655e+00 , 8.83270e-02 , 2.71821e+01 , 2.77254e+00 , 8.28891e-01 , -1.18949e+01 , -4.43098e+01 ];
a(4,:) = [3.92641e-01, 3.76713e-01 , -8.07320e-01 , 2.37642e-01 , 2.12900e+01 , 4.71617e+00 , 5.88363e-01 , -8.02412e+00 , -2.22831e+01 ];
a(5,:) = [2.96943e-01, 4.52079e-01 , 1.40366e-01 , 6.16413e-01 , 1.44028e+00 , 1.85520e+00 , -1.18608e-01 , 1.42665e+00 , 1.37032e-01 ];
a(6,:) = [4.23723e-01, 5.93807e-01 , 2.56190e-01 , 7.12637e-01 , 1.25008e+00 , 4.55736e+00 , -1.86445e-01 , 2.54586e+00 , 1.80676e+01 ];
a(7,:) = [6.90264e-01, 8.28961e-01 , -6.71227e-01 , 8.53265e-01 , 2.28154e+01 , 6.58273e+00 , 4.72375e-01 , -6.63849e+00 , -2.22066e+01 ];
MU_TABLE.FMUFANGLE_FREQUENCIES = a;
MU_COMPONENT.NAME(14)={'fa'};
MU_COMPONENT.PARAMETER(14).NUMBER=5;
MU_COMPONENT.PARAMETER(14).NAME={'Amp','Bdip','Adeg','DeGa','DeLo'};
MU_COMPONENT.PARAMETER(14).STEPBOUNDS=[0.01 0 0; 1 0 0; ...
                    2 0 0; 0.1 0 0;0.1 0 0]; % step lobound hibound
                                       % (0,0)=(-infty +infty)
MU_COMPONENT.DEFINITION(14)={'mufmufangle(p,data)'};
MU_COMPONENT.HELP(14)={['FMuF polycrystal in zero field, bent, with DeLo and/or DeGa decays']} ;

