function mucd
    
% new new attempt do define a logic for data/log
% see http://www.fis.unipr.it/home/roberto.derenzi/
%
% Changes data and log directory (GUI)
% All is dropdown menu driven. See Save/Quit.
% Select LOCATION (ISIS PSI or HOME) and LOG PATH (SELECTABLE or
% MIRROR) to choose the policy for the log path 
% Select FILENAME_PREFIX if your files are named differently
%
% Specifically:
% select HOME whenever working on your own laptop; 
% if you select AUTOLOGPATH='SELECTABLE' you are prompted also for
% a separate log path, free choice
% instead, if you select MIRROR then 
%
% under LIN data are in /home/musr/facility/run/instrument/sample/
% the keyword is facility, /home/musr/ is substituted by
% /home/user/ and facility/run/instrument/sample/ is appended
%
% under WIN data are where you choose, say 
% C:\Documents and Settings\user\My Documents\MuSR\facility\run ...
% \instrument\sample\
% the keyword is MuSR, and the logs go into
% C:\Documents and Settings\user\My Documents\Mulab\facility\run ...
% \instrument\sample\
%
% select ISIS when working from the instrument PC 
% data are on \\musr\data or \\emu\data 
% program is launched from ROOTDIR=
% C:\Documents and Settings\musr\My Documents\Mulab and for quick analysis 
% MU_PATH.LOG is mirrored on ROOTDIR\log, which can be renamed
% afterwards
% MU_GEAR.AUTOLOGPATH is overridden 
%
% select PSI when working from llc boxes 
% if MU_GEAR.AUTOLOGPATH is SELECTABLE
% data are physically on
% /afs/psi.ch/project/bulkmusr/data/gps/
% if one reads them there (fast option) with FILENAME_PREFIX='deltat_pta_gps'
% the log must go in /afs/psi.ch/user/x/xuser/mulab/live/
% if MU_GEAR.AUTOLOGPATH is MIRROR
% data are linked to
%  /afs/psi.ch/user/x/xuser/wherever/
% and logs go automatically into 
%  /afs/psi.ch/user/x/xuser/wherever/log/
%        
%
% See also MUPATH for old command driven options (only unix)
    global MU_PATH MU_GEAR
    
    if isfield(MU_PATH,'DATA')
        
        path=uigetdir(MU_PATH.DATA,['Choose the DATA path']);
    elseif isfield(MU_PATH,'ROOTDIR')
        path=uigetdir(MU_PATH.ROOTDIR,['Choose the DATA path']);
    else
        path=uigetdir(pwd,['Choose the DATA path']);
    end

    if path  %else skip to the bottom and return, user has chosen "cancel"
        slash='/';  % for unix
        if ispc
            slash='\'; % for windows
        end    
        if path(end)~=slash
            path=[path slash];  % make sure pathname ends with slash
        end

        % first store the data path!
        MU_PATH.DATA=path; % store data path in the appropriate global

        % then apply policy for log 
        switch MU_GEAR.LOCATION % first let's see where you think you
                                % are
          case 'ISIS' % on a PC in the EMU or MUSR cabins
                      % ignores MU_GEAR.AUTOLOGPATH
                      % reads data from \\instrument\data
                      % puts logs into [MU_PATH.ROOTDIR '\log\']
                      % (appropriate " " will be put by muload)
            if ~exist([MU_PATH.ROOTDIR 'log']) % create dir
                a=system(['mkdir ' MU_PATH.LOG 'log']);
                if a~=0 % if cannot create
                    disp(['Directory ' MU_PATH.LOG ...
                          'log\ cannot be created'])
                    disp('Log directory NOT set yet');
                    return  % abort
                end
            end
            MU_PATH.LOG=[MU_PATH.ROOTDIR 'log\'] % record log path
            disp('Mulab will store log files in directory')
            disp(['    ' MU_PATH.LOG])
            disp(['You may want to move its present content to ' ...
                  'another directory'])
          case 'PSI' % on a llc box at PSI
                     % distinguish if quick and dirty (read from
                     % original data) or separate logs (read from
                     % linked data)
                     % CANNOT BE A WIN BOX
            switch MU_GEAR.AUTOLOGPATH
              case 'Selectable'
                k=findstr(MU_PATH.ROOTDIR,'/user/'); %beginning of /user/... 
                kk=findstr(MU_PATH.ROOTDIR(k:end),'/'); % slash after username
                lastpart=MU_PATH.ROOTDIR(k:end); % path inside user home 
                MU_PATH.LOG=MU_PATH.ROOTDIR(1:findstr(...
                    MU_PATH.ROOTDIR,lastpart(kk(4):end))); %
                if ~exist([MU_PATH.LOG 'mulab'])
                    % create user/mulab/live if it does not exist
                    % ans set MU_PATH.LOG to it
                    a=system(['mkdir ' MU_PATH.LOG 'mulab/']);
                    if a~=0
                        disp(['Directory ' MU_PATH.LOG ...
                              'mulab/ cannot be created'])
                        disp('Log directory NOT set yet');
                        return
                    end
                    MU_PATH.LOG=[MU_PATH.LOG 'mulab/'];
                    if ~exist([MU_PATH.LOG 'live'])
                        a=system(['mkdir ' MU_PATH.LOG 'live/']);
                        if a~=0
                            disp(['Directory ' MU_PATH.LOG ...
                                  'mulab/ cannot be created'])
                            disp('Log directory NOT set yet');
                            return
                        end
                        MU_PATH.LOG=[MU_PATH.LOG 'live/'];
                    end
                end
 
              case 'Mirror'
                MU_PATH.LOG=[path 'log' slash]; % put log in a subdirectory 
                                                % of the data directory
                
                a=system(['mkdir ' MU_PATH.LOG]);
                if a~=0
                    disp(['Directory ' MU_PATH.LOG ' cannot be created'])
                    disp('Log directory NOT set yet');
                    return
                end
            end
          case 'home' % on your personal PC
                      % distinguish LIN from WIN
            if ispc
                switch MU_GEAR.AUTOLOGPATH
                  case 'Selectable'
                    % want to select freely the log dir
                    % starting the search from the data dir 
                    path=uigetdir(MU_PATH.DATA,['THE LOG PATH, NOW']);
	            if path(end)~=slash
            		path=[path slash];  % make sure pathname ends with slash
        	    end
                    MU_PATH.LOG=path;

                    if path==0
                        disp('Log directory NOT set yet');
                    end
                  case 'Mirror'
% the keyword is MuSR, and the logs go into
% C:\Documents and Settings\user\My Documents\Mulab\facility\run ...
% \instrument\sample\
                    k=findstr(upper(path),'MuSR'); % key='MuSR'
                    if ~k
                        disp(['Your data path is ' MU_PATH.DATA])
                        disp(['Mirror log on WIN looks for \MuSR\  ' ...
                              'in the path and substitutes it with ' ...
                              '\Mulab\'])
                        disp(['Your data path does not contain this ' ...
                              'keyword. You may choose Log path '...
                              'Selectable ' ...
                              'form the Save/Quit menu'])
                        return
                    end
                    % look for key=facility in path name
                    newpath=path(k:end); % second part, from key on
                    kk=findstr(newpath,'\'); % second \ is after MuSR
                    newpath=newpath(kk(2):end); % last part of log
                                                % path
                    MU_PATH.LOG=[path(1:k) 'Mulab' newpath]; 
                end
            elseif isunix
                switch MU_GEAR.AUTOLOGPATH
                  case 'Selectable'
                    % want to select freely the log dir
                    path=uigetdir(MU_PATH.DATA,['THE LOG PATH, NOW, pleeze']);
	            if path(end)~=slash
            		path=[path slash];  % make sure pathname ends with slash
        	    end
                    MU_PATH.LOG=path;
                    if path==0
                        disp('Log directory NOT set yet');
                    end
                  case 'Mirror'
                    
                    k=findstr(upper(path),MU_GEAR.FACILITY);
                    % look for key=facility in path name
                    newpath=path(k:end); % second part, from key on
                    [ok user]=unix('echo $USER'); % get user
                    logdir=strcat('/home/',user,'/mulab/'); % build
                                                            % first part
                    
                    % now check if the path exists
                    i2=[1 strfind(newpath,slash)];
                    dir=logdir;
                    a=0;
                    for k=1:length(i2)-1
                        dir=[dir newpath(i2(k):i2(k+1)-1)]; %adds a
                                                            %subdirectory
                                                            %at a time
                        if exist(dir)~=7 % check if it does not exist
                            disp(['Directory ' dir ...
                                  ' does not exist, creating ' ...
                                  'it'])
                            a=unix(['mkdir ' dir]); % makes it
                            if a~=0
                                disp(['Directory ' dir ...
                                      ' cannot be created'])
                                disp('Log directory NOT set yet');        
                                return
                            end
                        end
                    end
                    
                    MU_PATH.LOG=[logdir newpath]; %first plus
                                                  %second part
                    disp(['Log directory set to ' MU_PATH.LOG]);
                    % successfully set log in AUTOLOGPATH mode
                end
            else
                disp('Sorry, mulab may not work yet for your OS')
                return
            end
        end
    end
