function mufit
% new mufit 2015 with extracted modules for easier reading
%
% usage mufit
%
% This function executes the fminuit fit
% It requires prior execution of
% mu_initialize_models 

global MU_MODEL MU_DATA  
global MU_MODEL_F
global MU_ADD
global MU_PATH

if isfield(MU_DATA,'NRUN')
    muasymmetry;
    
    data=[MU_DATA.TIME(MU_MODEL.RANGE(1):MU_MODEL.RANGE(2)); ...
          MU_DATA.ASYMMETRY(MU_MODEL.RANGE(1):MU_MODEL.RANGE(2)); ...
          MU_DATA.ASYMERROR(MU_MODEL.RANGE(1):MU_MODEL.RANGE(2))];
    %size(data)
    %
    % set parnames
    [znpin stpbnd parname pf]=mupar(1); % use MU_MODEL
    parnames=[];
    for k=1:length(parname);
        parnames=[parnames ' ' parname{k}];
    end
    parnames=parnames(2:end); % remove starting blank

% first external new block

   muprofcn % recalculates array MU_MODEL.COMPONENT(k).SHARE to redistribute parameters
            % and MU_MODEL.COMPONENT(k).PARAMETER(j).MENU2MINUIT for linear relations

% execute FMINUIT

    [znpout,znepout,chi]=fminuit('mufcn','mnplot',znpin,data, ...
                                 '-s',stpbnd,'-c','mini;hesse;exit',...
                                 '-n',parnames);

% book keeping

    nu=length(data(1,:))-(length(znpin)-pf); % degrees of freedom
        
    par=0;
    MU_MODEL_F=MU_MODEL; % copy all, to start with, including new MENU2MINUIT
    if ~isempty(MU_ADD)
        MU_MODEL_F.ADD=MU_ADD;
    else
        MU_MODEL_F.ADD=[];
    end
    % add a few things which are not included in MU_MODEL
    % best fit details
    MU_MODEL_F.PAR=znpout;
    MU_MODEL_F.EPAR=znepout;
    MU_MODEL_F.NU=nu;
    MU_MODEL_F.CHI=chi;
    MU_MODEL_F.DATE=date;
    string=datestr(clock);
    MU_MODEL_F.TIME=string(13:20);
    % data details
    MU_MODEL_F.NRUN=MU_DATA.NRUN;
    MU_MODEL_F.DATAPATH=MU_PATH.DATA;
    MU_MODEL_F.SAMPLE=MU_DATA.SAMPLE;
    MU_MODEL_F.TEMPERATURE=MU_DATA.TEMPERATURE;
    MU_MODEL_F.FIELD=MU_DATA.FIELD;
    MU_MODEL_F.ORIENTATION=MU_DATA.ORIENTATION;
   
% now update best fit values as parameter staring guess 

    for k=1:MU_MODEL.COMPONENTNUMBER
        pn=MU_MODEL.COMPONENT(k).PARAMETERNUMBER;
        component=MU_MODEL.COMPONENT(k).NAME;
        par=0;
        for j=1:pn %MU_MODEL.COMPONENT(k).PARAMETERNUMBER
            par=par+1;
            share=MU_MODEL_F.COMPONENT(k).SHARE;
            if MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG=='~'|...
                    MU_MODEL.COMPONENT(k).PARAMETER(j).FLAG=='!'
                MU_MODEL_F.COMPONENT(k).PARAMETER(j).VALUE=...
                    znpout(share(par));
                MU_MODEL_F.COMPONENT(k).PARAMETER(j).ERROR= ...
                    znepout(share(par));
            else
                MU_MODEL_F.COMPONENT(k).PARAMETER(j).VALUE=0;
                MU_MODEL_F.COMPONENT(k).PARAMETER(j).ERROR=0;
                % not used: it is recalculted from its ingredients
            end
            
        end
    end

% write summary in command window, dat and log files    

    musummary(chi,nu,data(1,1),data(1,end),data(1,2)-data(1,1));

% plot results and residues

    muplotfit;

% save .fit files

    musavemodel(1) % dummy argument means save MU_MODEL_F
                   %    string=['To save fit results as initial guess type',...
                   %'    muupdatemodel'];
                   %    string=strvcat(string,['To check fit on different range type e.g.',...
                   %                        '    muplotfit(2,[1 500])']);
                   %    disp(string)
else
    disp('You must first load your data! ')
end

